@@ -633,7 +633,7 @@ int main(int argc, char *argv[]) {
 		(void)gettimeofday(&time_of_day, NULL);
 		volset_nr  =  (uint64_t) random();
 		volset_nr |= ((uint64_t) time_of_day.tv_sec) << 32;
-		sprintf(volset_name, "%016lx", volset_nr);
+		sprintf(volset_name, "%0"PRIx64, volset_nr);
 	}
 	if (!privol_name) {
 		privol_name = malloc(32);
